@@ -57,7 +57,6 @@
 
 #define DBUS_NAME_SUFFIX "Tracker3.Miner.Files"
 #define DBUS_PATH "/org/freedesktop/Tracker3/Miner/Files"
-#define LOCALE_FILENAME "locale-for-miner-apps.txt"
 
 static GMainLoop *main_loop;
 static guint cleanup_id;
@@ -142,33 +141,6 @@ log_option_values (TrackerConfig *config)
 #endif
 }
 
-static void
-miner_reset_applications (TrackerMiner *miner)
-{
-	const gchar *sparql;
-	GError *error = NULL;
-
-	sparql =
-		"DELETE { ?icon a rdfs:Resource } "
-		"WHERE { ?app a nfo:SoftwareApplication; nfo:softwareIcon ?icon }; "
-		"DELETE { ?app tracker:extractorHash ?h } "
-		"WHERE { ?app a nfo:SoftwareApplication ; "
-		"             tracker:extractorHash ?h } ";
-
-	/* Execute a sync update, we don't want the apps miner to start before
-	 * we finish this. */
-	tracker_sparql_connection_update (tracker_miner_get_connection (miner),
-	                                  sparql,
-	                                  NULL, &error);
-
-	if (error) {
-		/* Some error happened performing the query, not good */
-		g_critical ("Couldn't reset indexed applications: %s",
-		            error ? error->message : "unknown error");
-		g_error_free (error);
-	}
-}
-
 static GFile *
 get_cache_dir (TrackerDomainOntology *domain_ontology)
 {
@@ -178,99 +150,6 @@ get_cache_dir (TrackerDomainOntology *domain_ontology)
 	return g_file_get_child (cache, "files");
 }
 
-static void
-save_current_locale (TrackerDomainOntology *domain_ontology)
-{
-	GError *error = NULL;
-	gchar *locale = tracker_locale_get (TRACKER_LOCALE_LANGUAGE);
-	GFile *cache = get_cache_dir (domain_ontology);
-	gchar *cache_path = g_file_get_path (cache);
-	gchar *locale_file;
-
-	locale_file = g_build_filename (cache_path, LOCALE_FILENAME, NULL);
-	g_free (cache_path);
-
-	TRACKER_NOTE (CONFIG, g_message ("Saving locale used to index applications"));
-	TRACKER_NOTE (CONFIG, g_message ("  Creating locale file '%s'", locale_file));
-
-	if (locale == NULL) {
-		locale = g_strdup ("");
-	}
-
-	if (!g_file_set_contents (locale_file, locale, -1, &error)) {
-		g_message ("  Could not set file contents, %s",
-		           error ? error->message : "no error given");
-		g_clear_error (&error);
-	}
-
-	g_object_unref (cache);
-	g_free (locale);
-	g_free (locale_file);
-}
-
-static gboolean
-detect_locale_changed (TrackerMiner          *miner,
-		       TrackerDomainOntology *domain_ontology)
-{
-	GFile *cache;
-	gchar *cache_path;
-	gchar *locale_file;
-	gchar *previous_locale = NULL;
-	gchar *current_locale;
-	gboolean changed;
-
-	cache = get_cache_dir (domain_ontology);
-	cache_path = g_file_get_path (cache);
-	locale_file = g_build_filename (cache_path, LOCALE_FILENAME, NULL);
-	g_object_unref (cache);
-	g_free (cache_path);
-
-	if (G_LIKELY (g_file_test (locale_file, G_FILE_TEST_EXISTS))) {
-		gchar *contents;
-
-		/* Check locale is correct */
-		if (G_LIKELY (g_file_get_contents (locale_file, &contents, NULL, NULL))) {
-			if (contents &&
-			    contents[0] == '\0') {
-				g_critical ("  Empty locale file found at '%s'", locale_file);
-				g_free (contents);
-			} else {
-				/* Re-use contents */
-				previous_locale = contents;
-			}
-		} else {
-			g_critical ("  Could not get content of file '%s'", locale_file);
-		}
-	} else {
-		TRACKER_NOTE (CONFIG, g_message ("  Could not find locale file:'%s'", locale_file));
-	}
-
-	g_free (locale_file);
-
-	current_locale = tracker_locale_get (TRACKER_LOCALE_LANGUAGE);
-
-	/* Note that having both to NULL is actually valid, they would default
-	 * to the unicode collation without locale-specific stuff. */
-	if (g_strcmp0 (previous_locale, current_locale) != 0) {
-		TRACKER_NOTE (CONFIG, g_message ("Locale change detected from '%s' to '%s'...",
-		                      previous_locale, current_locale));
-		changed = TRUE;
-	} else {
-		TRACKER_NOTE (CONFIG, g_message ("Current and previous locales match: '%s'", previous_locale));
-		changed = FALSE;
-	}
-
-	g_free (current_locale);
-	g_free (previous_locale);
-
-	if (changed) {
-		TRACKER_NOTE (CONFIG, g_message ("Resetting nfo:Software due to locale change..."));
-		miner_reset_applications (miner);
-	}
-
-	return changed;
-}
-
 static gboolean
 signal_handler (gpointer user_data)
 {
@@ -542,15 +421,6 @@ miner_finished_cb (TrackerMinerFS *fs,
 	}
 }
 
-static void
-dummy_log_handler (const gchar    *domain,
-                   GLogLevelFlags  log_level,
-                   const gchar    *message,
-                   gpointer        user_data)
-{
-	return;
-}
-
 static void
 graphs_created_cb (GObject      *source,
                    GAsyncResult *res,
@@ -565,32 +435,20 @@ graphs_created_cb (GObject      *source,
 }
 
 static gint
-check_eligible (void)
+check_eligible (TrackerIndexingTree *indexing_tree,
+                TrackerStorage      *storage)
 {
-	TrackerSparqlConnection *sparql_conn;
-	TrackerMiner *miner_files;
-	TrackerIndexingTree *indexing_tree;
-	TrackerDomainOntology *domain_ontology;
-	TrackerConfig *config;
-	GFile *ontology;
+	TrackerController *controller;
 	GFile *file;
 	GFileInfo *info;
 	GError *error = NULL;
 	gchar *path;
-	guint log_handler_id;
 	gboolean exists = TRUE;
 	gboolean indexable;
 	gboolean parents_indexable = TRUE;
 	gboolean is_dir;
 
-	/* Set log handler for library messages */
-	log_handler_id = g_log_set_handler (NULL,
-	                                    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
-	                                    dummy_log_handler,
-	                                    NULL);
-
-	g_log_set_default_handler (dummy_log_handler, NULL);
-
+	controller = tracker_controller_new (indexing_tree, storage);
 
 	/* Start check */
 	file = g_file_new_for_commandline_arg (eligible);
@@ -616,7 +474,6 @@ check_eligible (void)
 		is_dir = FALSE;
 	}
 
-	config = tracker_config_new ();
 	path = g_file_get_path (file);
 
 	g_print (exists ?
@@ -626,34 +483,6 @@ check_eligible (void)
 
 	g_print ("\n");
 
-	domain_ontology = tracker_domain_ontology_new (domain_ontology_name, NULL, &error);
-	ontology = tracker_domain_ontology_get_ontology (domain_ontology);
-	tracker_domain_ontology_unref (domain_ontology);
-
-	sparql_conn = tracker_sparql_connection_new (0,
-	                                              NULL,
-	                                              ontology,
-	                                              NULL,
-	                                              NULL);
-	if (!sparql_conn) {
-		g_object_unref (info);
-		return EXIT_FAILURE;
-	}
-
-	/* Create new TrackerMinerFiles object */
-	config = tracker_config_new ();
-	miner_files = tracker_miner_files_new (sparql_conn, config,
-	                                       domain_ontology_name, NULL);
-	g_object_unref (config);
-
-	if (!miner_files) {
-		g_object_unref (info);
-		g_object_unref (sparql_conn);
-		return EXIT_FAILURE;
-	}
-
-	indexing_tree = tracker_miner_fs_get_indexing_tree (TRACKER_MINER_FS (miner_files));
-
 	indexable = tracker_indexing_tree_file_is_indexable (indexing_tree, file, info);
 
 	if (!indexable) {
@@ -727,15 +556,10 @@ check_eligible (void)
 		         _("File is eligible to be indexed"));
 	}
 
-	if (log_handler_id != 0) {
-		/* Unset log handler */
-		g_log_remove_handler (NULL, log_handler_id);
-	}
-
 	g_free (path);
 	g_object_unref (file);
-	g_object_unref (miner_files);
 	g_object_unref (info);
+	g_object_unref (controller);
 
 	return (indexable && parents_indexable) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
@@ -918,6 +742,8 @@ main (gint argc, gchar *argv[])
 	TrackerMinerProxy *proxy;
 	GDBusConnection *connection;
 	TrackerSparqlConnection *sparql_conn;
+	TrackerIndexingTree *indexing_tree;
+	TrackerStorage *storage;
 	TrackerDomainOntology *domain_ontology;
 	TrackerController *controller;
 #if GLIB_CHECK_VERSION (2, 64, 0)
@@ -964,8 +790,11 @@ main (gint argc, gchar *argv[])
 		return EXIT_SUCCESS;
 	}
 
+	indexing_tree = tracker_indexing_tree_new ();
+	storage = tracker_storage_new ();
+
 	if (eligible) {
-		return check_eligible ();
+		return check_eligible (indexing_tree, storage);
 	}
 
 	domain_ontology = tracker_domain_ontology_new (domain_ontology_name, NULL, &error);
@@ -1038,20 +867,13 @@ main (gint argc, gchar *argv[])
 	}
 
 	/* Create new TrackerMinerFiles object */
-	miner_files = tracker_miner_files_new (sparql_conn, config,
-	                                       domain_ontology_name, &error);
-	if (!miner_files) {
-		g_critical ("Couldn't create new Files miner: '%s'",
-		            error ? error->message : "unknown error");
-		g_object_unref (config);
-		return EXIT_FAILURE;
-	}
+	miner_files = tracker_miner_files_new (sparql_conn,
+	                                       indexing_tree,
+	                                       storage,
+	                                       config,
+	                                       domain_ontology);
 
-	controller = tracker_controller_new (tracker_miner_fs_get_indexing_tree (TRACKER_MINER_FS (miner_files)),
-	                                     tracker_miner_files_get_storage (TRACKER_MINER_FILES (miner_files)));
-
-	/* If the locales changed, we need to reset some things first */
-	detect_locale_changed (TRACKER_MINER (miner_files), domain_ontology);
+	controller = tracker_controller_new (indexing_tree, storage);
 
 	proxy = tracker_miner_proxy_new (miner_files, connection, DBUS_PATH, NULL, &error);
 	if (error) {
@@ -1141,10 +963,8 @@ main (gint argc, gchar *argv[])
 
 	g_debug ("Shutdown started");
 
-	if (!dry_run && miners_timeout_id == 0 && !miner_needs_check (miner_files)) {
+	if (!dry_run && miners_timeout_id == 0 && !miner_needs_check (miner_files))
 		tracker_miner_files_set_need_mtime_check (TRACKER_MINER_FILES (miner_files), FALSE);
-		save_current_locale (domain_ontology);
-	}
 
 	finish_endpoint_thread ();
 
@@ -1162,6 +982,9 @@ main (gint argc, gchar *argv[])
 	tracker_sparql_connection_close (sparql_conn);
 	g_object_unref (sparql_conn);
 
+	g_clear_object (&indexing_tree);
+	g_clear_object (&storage);
+
 #if GLIB_CHECK_VERSION (2, 64, 0)
 	g_signal_handlers_disconnect_by_func (memory_monitor, on_low_memory, NULL);
 	g_object_unref (memory_monitor);
