@@ -21,10 +21,12 @@
 #ifndef __TRACKER_MINER_RSS_H__
 #define __TRACKER_MINER_RSS_H__
 
-#include <libtracker-miner/tracker-miner.h>
+#include <libtracker-miners-common/tracker-common.h>
 
 #include <libtracker-sparql/tracker-sparql.h>
 
+#include "tracker-miner-online.h"
+
 G_BEGIN_DECLS
 
 #define TRACKER_TYPE_MINER_RSS         (tracker_miner_rss_get_type())
