@@ -25,6 +25,10 @@
 
 #include "tracker-decorator.h"
 
+#ifdef HAVE_POSIX_FADVISE
+#include <fcntl.h>
+#endif
+
 #define QUERY_BATCH_SIZE 200
 #define DEFAULT_BATCH_SIZE 200
 
@@ -87,7 +91,6 @@ enum {
 enum {
 	ITEMS_AVAILABLE,
 	FINISHED,
-	RAISE_ERROR,
 	LAST_SIGNAL
 };
 
@@ -178,6 +181,48 @@ G_DEFINE_BOXED_TYPE (TrackerDecoratorInfo,
                      tracker_decorator_info_ref,
                      tracker_decorator_info_unref)
 
+static void
+hint_file_needed (GFile    *file,
+                  gboolean  needed)
+{
+#ifdef HAVE_POSIX_FADVISE
+	g_autofree gchar *path = NULL;
+	int fd;
+
+	path = g_file_get_path (file);
+	if (!path)
+		return;
+
+	fd = tracker_file_open_fd (path);
+	posix_fadvise (fd, 0, 0,
+	               needed ? POSIX_FADV_WILLNEED : POSIX_FADV_DONTNEED);
+	close (fd);
+#endif /* HAVE_POSIX_FADVISE */
+}
+
+static void
+tracker_decorator_info_hint_needed (TrackerDecoratorInfo *info,
+                                    gboolean              needed)
+{
+	g_autoptr (GFile) file = NULL;
+
+	file = g_file_new_for_uri (info->url);
+	hint_file_needed (file, needed);
+}
+
+static void
+decorator_hint_next_file_needed (TrackerDecorator *decorator)
+{
+	TrackerDecoratorPrivate *priv =
+		tracker_decorator_get_instance_private (decorator);
+	TrackerDecoratorInfo *next_info;
+	g_autoptr (GFile) file = NULL;
+
+	next_info = g_queue_peek_head (&priv->item_cache);
+	if (next_info)
+		tracker_decorator_info_hint_needed (next_info, TRUE);
+}
+
 static void
 decorator_update_state (TrackerDecorator *decorator,
                         const gchar      *message,
@@ -244,6 +289,20 @@ retry_synchronously (TrackerDecorator *decorator,
 	}
 }
 
+static void
+tag_success (TrackerDecorator *decorator,
+             GPtrArray        *commit_buffer)
+{
+	guint i;
+
+	for (i = 0; i < commit_buffer->len; i++) {
+		TrackerExtractInfo *info;
+
+		info = g_ptr_array_index (commit_buffer, i);
+		tracker_error_report_delete (tracker_extract_info_get_file (info));
+	}
+}
+
 static void
 decorator_commit_cb (GObject      *object,
                      GAsyncResult *result,
@@ -266,6 +325,8 @@ decorator_commit_cb (GObject      *object,
 
 		g_debug ("SPARQL error detected in batch, retrying one by one");
 		retry_synchronously (decorator, priv->commit_buffer);
+	} else {
+		tag_success (decorator, priv->commit_buffer);
 	}
 
 	g_clear_pointer (&priv->commit_buffer, g_ptr_array_unref);
@@ -392,6 +453,8 @@ decorator_task_done (GObject      *object,
 	priv = tracker_decorator_get_instance_private (decorator);
 	extract_info = g_task_propagate_pointer (G_TASK (result), &error);
 
+	tracker_decorator_info_hint_needed (info, FALSE);
+
 	if (!extract_info) {
 		if (error) {
 			g_warning ("Task for '%s' finished with error: %s\n",
@@ -548,6 +611,7 @@ decorator_cache_items_cb (GObject      *object,
 	} else if (g_queue_is_empty (&priv->item_cache) && priv->processing) {
 		decorator_finish (decorator);
 	} else if (queue_was_empty) {
+		decorator_hint_next_file_needed (decorator);
 		g_signal_emit (decorator, signals[ITEMS_AVAILABLE], 0);
 	}
 }
@@ -879,16 +943,6 @@ tracker_decorator_class_init (TrackerDecoratorClass *klass)
 		              G_STRUCT_OFFSET (TrackerDecoratorClass, finished),
 		              NULL, NULL, NULL,
 		              G_TYPE_NONE, 0);
-
-	signals[RAISE_ERROR] =
-		g_signal_new ("raise-error",
-		              G_OBJECT_CLASS_TYPE (object_class),
-		              G_SIGNAL_RUN_LAST,
-		              0, NULL, NULL, NULL,
-		              G_TYPE_NONE, 3,
-			      G_TYPE_FILE,
-			      G_TYPE_STRING,
-			      G_TYPE_STRING);
 }
 
 static void
@@ -954,6 +1008,7 @@ tracker_decorator_next (TrackerDecorator  *decorator,
 		return NULL;
 
 	TRACKER_NOTE (DECORATOR, g_message ("[Decorator] Next item %s", info->url));
+	decorator_hint_next_file_needed (decorator);
 
 	return info;
 }
