@@ -48,9 +48,7 @@ struct TrackerExtractDecoratorClass {
 GType              tracker_extract_decorator_get_type (void) G_GNUC_CONST;
 
 TrackerDecorator * tracker_extract_decorator_new (TrackerSparqlConnection  *connection,
-                                                  TrackerExtract           *extractor,
-                                                  GCancellable             *cancellable,
-                                                  GError                  **error);
+                                                  TrackerExtract           *extractor);
 
 G_END_DECLS
 
