@@ -30,6 +30,8 @@
 #include <gio/gunixinputstream.h>
 #include <gio/gunixfdlist.h>
 
+#include <libtracker-miners-common/tracker-common.h>
+
 #include <libtracker-extract/tracker-extract.h>
 
 #include "tracker-extract.h"
@@ -45,8 +47,6 @@ G_DEFINE_QUARK (TrackerExtractError, tracker_extract_error)
 
 #define DEADLINE_SECONDS 30
 
-#define DEFAULT_MAX_TEXT 1048576
-
 extern gboolean debug;
 
 typedef struct {
@@ -59,8 +59,6 @@ typedef struct {
 	GHashTable *statistics_data;
 	GList *running_tasks;
 
-	gint max_text;
-
 	/* used to maintain the running tasks
 	 * and stats from different threads
 	 */
@@ -86,7 +84,6 @@ typedef struct {
 	gchar *file;
 	gchar *mimetype;
 	const gchar *graph;
-	gint max_text;
 
 	TrackerExtractMetadataFunc func;
 	GModule *module;
@@ -128,7 +125,6 @@ tracker_extract_init (TrackerExtract *object)
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 	priv->single_thread_extractors = g_hash_table_new (NULL, NULL);
-	priv->max_text = DEFAULT_MAX_TEXT;
 
 #ifdef G_ENABLE_DEBUG
 	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
@@ -292,7 +288,7 @@ get_file_metadata (TrackerExtractTask  *task,
 	*info_out = NULL;
 
 	file = g_file_new_for_uri (task->file);
-	info = tracker_extract_info_new (file, task->mimetype, task->graph, task->max_text);
+	info = tracker_extract_info_new (file, task->mimetype, task->graph);
 	g_object_unref (file);
 
 	if (!task->mimetype || !*task->mimetype) {
@@ -309,7 +305,7 @@ get_file_metadata (TrackerExtractTask  *task,
 
 		task->success = (task->func) (info, error);
 	} else {
-		TrackerResource *resource;
+		g_autoptr (TrackerResource) resource = NULL;
 
 		/* Dummy extractor */
 		resource = tracker_resource_new (NULL);
@@ -346,7 +342,6 @@ extract_task_new (TrackerExtract *extract,
                   GAsyncResult   *res,
                   GError        **error)
 {
-	TrackerExtractPrivate *priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
 	TrackerExtractTask *task;
 	gchar *mimetype_used;
 
@@ -383,7 +378,6 @@ extract_task_new (TrackerExtract *extract,
 	task->file = g_strdup (uri);
 	task->mimetype = mimetype_used;
 	task->extract = extract;
-	task->max_text = priv->max_text;
 
 	if (task->res) {
 		task->deadline =
@@ -537,6 +531,9 @@ get_metadata (TrackerExtractTask *task)
 static gpointer
 single_thread_get_metadata (GAsyncQueue *queue)
 {
+	if (!tracker_seccomp_init ())
+		g_assert_not_reached ();
+
 	while (TRUE) {
 		TrackerExtractTask *task;
 
@@ -708,6 +705,9 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 	                                                          NULL,
 	                                                          &task->func);
 
+	if (!tracker_seccomp_init ())
+		g_assert_not_reached ();
+
 	if (!filter_module (object, task->module) &&
 	    get_file_metadata (task, &info, NULL)) {
 		resource = tracker_extract_info_get_resource (info);
@@ -790,12 +790,3 @@ tracker_extract_file_finish (TrackerExtract  *extract,
 
 	return g_task_propagate_pointer (G_TASK (res), error);
 }
-
-void
-tracker_extract_set_max_text (TrackerExtract *extract,
-                              gint            max_text)
-{
-	TrackerExtractPrivate *priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
-
-	priv->max_text = max_text;
-}
